<template>
  <view class="nut-tab-pane" v-if="shouldBeRender" :style="paneStyle">
    <slot></slot>
  </view>
</template>

<script setup lang="ts">
import { CSSProperties, inject, ref, computed, watch } from 'vue';

defineOptions({
  name: 'ProTabPane',
});

const props = defineProps({
  title: {
    type: [String, Number],
    default: '',
  },
  subTitle: {
    type: [String, Number],
    default: '',
  },
  paneKey: {
    type: [String, Number],
    default: '',
  },
  disabled: {
    type: Boolean,
    default: false,
  },
  lazy: {
    type: Boolean,
    default: true,
  },
  badgeValue: {
    type: Number,
    default: 0,
  },
});

const parentOption = inject('tabsOpiton') as any;

const paneStyle = computed(() => {
  return {
    display:
      parentOption.animatedTime.value === 0 && props.paneKey !== parentOption.activeKey.value
        ? 'none'
        : undefined,
  } as CSSProperties;
});

const active = computed(() => props.paneKey === parentOption.activeKey.value);

const loaded = ref(active.value);

const shouldBeRender = computed(() => !props.lazy || loaded.value || active.value);

watch(active, (val) => {
  if (val) loaded.value = true;
});
</script>
